package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M35J0``,````$````__\``+@`````````0```````````````````````````
M````````````````````@`````X?N@X`M`G-(;@!3,TA5&AI<R!P<F]G<F%M
M(&-A;FYO="!B92!R=6X@:6X@1$]3(&UO9&4N#0T*)`````````!010``3`$&
M`&CLQ$D``````````.``#P,+`0(X`$````#.````!```@!(````0````4```
M``!````0`````@``!`````$````$```````````0`0``!```S]P```,`````
M`"```!``````$```$````````!````````````````#0``#<"@```.```'`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"YT97AT````1#X````0````0`````0`````````
M`````````&```&`N9&%T80```'``````4`````(```!$````````````````
M``!```#`+G)D871A``#07````&````!>````1@``````````````````0```
M0"YB<W,`````0`(```#``````````````````````````````(```,`N:61A
M=&$``-P*````T`````P```"D``````````````````!```#`+G)S<F,```!P
M(````.`````B````L```````````````````0```P```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````%6)Y8/L&(E=^(M%
M"#';B77\BP`Q]HL`/9$``,!W0SV-``#`<EN^`0```,<$)`@````QTHE4)`3H
M1#8``(/X`71ZA<!T#L<$)`@```#_T+O_____B=B+=?R+7?B)[%W"!``]E```
MP'3"=TH]DP``P'2TB=B+=?R+7?B)[%W"!`"0/04``,!T6ST=``#`=<7'!"0$
M````,?:)="0$Z.`U``"#^`%T:H7`=*K'!"0$````_]#KFCV6``#`Z]''!"0(
M````N`$```")1"0$Z+`U``"%]@^$=O___^AS.0``Z6S____'!"0+````,<")
M1"0$Z(PU``"#^`%T,(7`#X12____QP0D"P```/_0Z3_____'!"0$````N0$`
M``")3"0$Z%PU``#I)?___\<$)`L```"X`0```(E$)`3H0C4``.D+____C;8`
M````C;PG`````%6)Y5.#["3'!"0`$$``Z*TV``"#[`3HY3<``.C@.```QT7X
M`````(U%^(E$)!"A(%!``,<$)`3`0`")1"0,C47TB40D"+@`P$``B40D!.@-
M-0``H7#!0`"%P'1DHS!00`"+%8#20`"%T@^%H0```(/ZX'0?H7#!0`")1"0$
MH8#20`"+0#")!"3HPS0``(L5@-)``(/ZP'0HH7#!0`")1"0$H8#20`"+0%")
M!"3HGS0``.L-D)"0D)"0D)"0D)"0D.A[-```BQ4P4$``B1#H_C8``(/D\.C6
M-@``Z$$T``"+`(E$)`BA`,!``(E$)`2A!,!``(D$).A5+P``B</H#C0``(D<
M).C&-0``C;8`````B40D!*&`TD``BT`0B00DZ"PT``"+%8#20`#I0/___Y!5
MB>6#[`C'!"0!````_Q5<TD``Z+C^__^0C;0F`````%6)Y8/L",<$)`(```#_
M%5S20`#HF/[__Y"-M"8`````58L-I-)``(GE7?_AC70F`%6+#8S20`")Y5W_
MX9"0D)!5B>5=Z2<X``"0D)"0D)"058GE@^P8Z#4S``")!"2Y!&!``+H@1D``
MB4PD#+D.8$``B50D"(E,)`3H(C,``.@-,P``B00DN@1@0`"Y$$9``(E4)`RZ
M*F!``(E,)`B)5"0$Z/HR``#)PY"-M"8`````58GE5U93@^P<A<")1?")5>QT
M?>@(,P``BPB%R71RBTWP#[8!A,`/E<(\/0^5P`^VP(7"=!5!#[8!A,`/E<(\
M/0^5P`^VP(7"=>N+7?")S^C,,@``*=^+&(LSA?9T,F:0B7PD"(M5\(DT)(E4
M)`3H/30``(7`=0:`/#<]=!V#PP2+,X7V==J-=@"-O"<`````,<"#Q!Q;7E]=
MP^B!,@``BQ"+1>PIT\'[`HD8C40^`>OAZPV0D)"0D)"0D)"0D)"058GEC57\
M@^P(Z#+____)PU6)Y5=6B=93@^PLB47L,<"`.CT/E,`!QHDT).B0,P``B47H
MBT7LC57PZ`+___^%P(G'#X3W````B00DZ'`S```[1>@/@\X```"+?>SK`V:0
M1P^V!X3`#Y7"/#T/E<`/ML"%PG7KZ.8Q``"+5?")5=B+`(E%U.B6,0``B00D
MZ%XQ``")P^B',0``B00DZ$\Q``"+$(M%[(M-Z"G'C40/`HE$)`2+`XD$)/\2
MBU78BTW4A<")!)&Z_____W11Z(\Q``"+$(M%\(L\@HM5[`^V`D*)5>R$P'0A
M/#WK&Y"-="8`B`>+3>Q'#[8108E-[(32B-!T!8#Z/77HQ@<]1XUT)@`/M@9&
MB`='A,!U]3'2@\0LB=!;7E]=PP^V!D:(!T>$P'3I#[8&1H@'1X3`=>KKW.@<
M,0``BQC'1>0`````ZP>0_T7D@\,$BP.%P'7TBST0P$``A?\/A8(```"Y`0``
M`(D-$,!``.BF,```B00DZ&XP``")P^B7,```B00DZ%\P``"+?>2+$,'G`HU'
M"(E$)`2+`XD$)/\2NO____^%P(G##X1G____Z*4P``")?"0(BP")'"2)1"0$
MZ.,Q``#HCC```(D8Z(<P``"+`#'2BTWDB52(!(E-\.EM_O__Z&\P``")1>#H
M9S```(E%W.@?,```B00DZ.<O``")P^@0,```B00DZ-@O``"+3>2+$(T$C0@`
M``")1"0(BTW<BP&)1"0$BP.)!"3_4@2+5>")`N@=,```BQBZ_____X7;=8;I
MRO[__XVV`````(V\)P````!5B>53@^P$B<.-M"8`````C57XB=CHQOS__X7`
M=!OHW2\``(L0BT7XC12"BT($A<")`G3<@\($Z_)86UW#C78`53'`B>5=PXGV
MC;PG`````%6X/V!``(GE5U93@>Q,`0``BWT(Z#?]__^)A=3^__^X!`$``(E$
M)`B-A=C^__^)1"0$QP0D`````.A2,0``@^P,A<!U*Z$`4$``B3PDB40D!.B:
M,```A<!T/(GZN$A@0`#H^OS__XUE](GX6UY?7<.-E=C^__^X2&!``(VUV/[_
M_^C:_/__B30DZ*(P``"-9?1;7E]=PXD\).AR,```B870_O__H0100`")1"0$
MBT4,B00DC;8`````C;PG`````.@;,```A<")PW2/@#@`=06[56!``(N%U/[_
M_X7`=!J)7"0$B[74_O__B30DZ-\O``"%P`^$UP```(D<).@/,```BPT`4$``
MB<(/M@$X1!/_=2*-M"8`````C;PG`````$K&!!,`BPT`4$``#[8!.$03_W3L
MB[70_O__C40R`3T#`0``#X\1____B4PD#+A78$``B40D!(V%V/[__XE<)`B)
M?"00B00DZ%0O``#H_RT``(D$).BG+0``B<;H\"T``(D$).BH+0``B</HX2T`
M`(D$).B9+0``BQ")="0(C;78_O__B70D!(L#B00D_U)0A<!U'>BX+0``B00D
MZ&`M```/MT`&)0#P```]`(```'05H0100`#'!"0`````B40D!.G;_O__Z(8M
M``")!"3H/BT``(G#Z'<M``")!"3H+RT``(L0N`$```")1"0(B70D!(L#B00D
M_Q*%P'6UC978_O__N$A@0`#H-?O__XV%V/[__XD$).CW+@``Z5#^__]FD%6)
MY5:+=0A3B?,/M@:$P'0OB,*A`%!```^V`.L,C78`#[81B<N$TG07.,*-2P%U
M\`^V$8G.B<N$TG7ND(UT)@!;B?!>7<.-=@"-O"<`````58GE4X/L%(M="(7;
M=`H/M@.$P(A%^W48QT4(56!``(/$%%M=Z7<N``"-M"8`````B1PDZ$@N``"-
M#!B-4?\YVG8^H0!00``/M@`X0?]U"I!*.=IV*S@"=/<YVG8CBPT`4$``ZP5*
M.=IV%@^V`3@"=?3K#9"0D)"0D)"0D)"0D)`YVG1*BPT`4$``C;8`````2CG:
M=@</M@$X`G3T*=HQR8U"`CT$`0``=QR)7"0$C4(!B40D",<$)"#`0`#H7RT`
M`+D@P$``@\04B<A;7<,/ME7[H0!00``Z$`^$.?___XE%".DX____B?:-O"<`
M````58GE5U:#[#"A8&!``(E%R*%D8$``B47,H6A@0`")1="A;&!``(E%U*%P
M8$``B478H71@0`")1=RA>&!``(E%X*%\8$``B47D#[<%@&!``&:)1>BX@F!`
M`.C3^___N))@0`#HR?O__[@_8$``Z+_[__^XGF!``.BU^___N*A@0`#HJ_O_
M_[BR8$``Z*'[__^X2&!``.B7^___N+Q@0`#HC?O__[C%8$``Z(/[__^XT&!`
M`.@9^?__A<!T#(G"N*A@0`#H&?G__[CA8$``Z/_X__^%P'0,B<*X\V!``.C_
M^/__N/Y@0`#HY?C__X7`="*)PK@_8$``Z.7X__^Z#F%``+B"8$``Z-;X__^#
MQ#!>7UW#N!!A0`#HM?C__X7`B<)T![B>8$``Z\[\OR%A0`"-1=FY"@```(G&
M\Z9UOXU5X[B>8$``Z["-=@"-O"<`````58GE@^P(H0A00`"#^/]T`LG#N)Y@
M0`#H9/C__S'2A<!T'@^V`(3`=!<\,'03N@$```"-M"8`````C;PG`````(D5
M"%!``(G0R<.-M@````!5,<F)Y5=64XG#@>Q<`0``B86D_O__@\,<C;0F````
M`(LS@\,$B?*)\,'B"('B``#_`,'N",'@&`G0B?*!X@#_``#![A`)T`GPB82-
MJ/[__T&#^0]^RKD0````D(UT)@"+A(V(_O__BYR-G/[__XN4C7#^__^+O(UH
M_O__,=@QT#'XT<")A(VH_O__08/Y3W[/BX6D_O__BU`$BSB)E:#^__^+2`B)
M^L'"!8F-G/[__XM`#(N-H/[__XNUG/[__XF%F/[__XN%H/[__XN=F/[__R'Q
M]]"+M:C^__\AV`G!BYV<_O__`<J+C:3^__^+01#!A:#^__\>`<*+C:#^__\!
M\HGXC;*9>8):]]`A^2'8B?()P8N%K/[__\'"!0'*BXV8_O__P<<>`<H!PHGP
MC9J9>8):]]`CA:#^__^)\2'YB=K!QA[!P@4)P8N%G/[__P'*BXVP_O__`<*)
MV`'*]]")V2'X(?$)P8'"F7F"6HN%H/[__XF5F/[__\'"!0'*`<*+A;3^__^+
MC9C^__\!PHN%F/[__X'"F7F"6HF5G/[__\'#'B'9P868_O__'O?0(?`)P<'"
M!8N%N/[__P'*`?J+C9S^__\!PHN%F/[__X'"F7F"6HF5H/[__\'"!2'!BX6<
M_O__]]`AV`G!BX6\_O__`<K!A9S^__\>`?*+C:#^__\!PHN%G/[__XNUF/[_
M_XVZF7F"6B'!BX6@_O__P86@_O__'HGZP<(%]]`A\`G!B[7`_O__`<J)^(N-
MH/[__P':]]"+G9S^__\!\HVRF7F"6B'8B?(A^0G!P<(%`<J+C9C^__^+A<3^
M__\!R@'"B?#WT,'''B.%H/[__XV:F7F"6HGQ(?F)VL'"!0G!BX6<_O__`<J+
MC<C^___!QAX!PHG8`<KWT(G9(?@A\0G!@<*9>8):BX6@_O__B968_O__P<(%
M`<H!PHN%S/[__\'#'HN-F/[__P'"BX68_O__P868_O__'H'"F7F"6B'9B96<
M_O__]]`A\`G!P<(%BX70_O__`<H!^HN-G/[__P'"BX68_O__@<*9>8):B96@
M_O__P<(%(<&+A9S^___WT"'8"<$!RHN%U/[__P'RP86<_O__'HN-H/[__P'"
MBX6<_O__C;J9>8):B[68_O__B?HAP8N%H/[__\'"!??0(?`)P8NUV/[__P'*
MP86@_O__'@':BXV@_O__BYV<_O__`?*)^(VRF7F"6O?0(?DAV(GR"<'!P@6+
MA=S^__\!RHN-F/[__\'''@'*`<*)\/?0(X6@_O__C9J9>8):B?$A^8G:P<(%
M"<&+A9S^__\!RHN-X/[__\'&'@'"B=@!RO?0B=DA^"'Q"<&!PIEY@EJ+A:#^
M__^)E9C^___!P@4!R@'"BX7D_O__BXV8_O__P<,>`<*+A9C^___!A9C^__\>
M@<*9>8):(=F)E9S^___WT"'P"<'!P@6+A>C^__\!R@'ZBXV<_O__`<*+A9C^
M__^!PIEY@EJ)E:#^___!P@4AP8N%G/[__\&%G/[__Q[WT"'8"<&+A>S^__\!
MR@'RBXV@_O__B[68_O__`<*+A9S^__^-NIEY@EJ)^L'"!2'!BX6@_O__P86@
M_O__'O?0(?`)P8NU\/[__P'*`=J+C:#^__^)^(N=G/[__P'R]]"-LIEY@EHA
M^8GR(=C!P@4)P8N%F/[__P'*P<<>BYWT_O__BXV@_O__`<(!VHV:F7F"6HGR
M,?J)V#'*P<`%BXWX_O__`="+E9S^___!QAX!T`'(B=H%H>O9;HF%F/[__S'R
MP<`%,?J+C?S^___!PQX!T(N5H/[__P'0BY68_O__`<@%H>O9;HF%G/[__S':
MP<`%P868_O__'C'R`="+E0#___\!^(N]F/[__P'0BY6<_O__!:'KV6Z)A:#^
M___!P`4Q^C':`=`!\(NU!/___XN5H/[__P'PP86<_O__'HNUF/[__XVXH>O9
M;L&%H/[__QZ)^(N-G/[__\'`!3'*,?(!T(N5H/[__P'8BYT(____BXV<_O__
M,?K!QQX!V(VPH>O9;HGP,<J+G0S____!P`6+C:#^__\!T(N5F/[__P'0`=B-
MF*'KV6Z)\C'ZB=@QRHN-$/___\'`!0'0BY6<_O__P<8>`=`!R(G:!:'KV6Z+
MC13___^)A9C^__\Q\L'`!3'ZP<,>`="+E:#^__\!T(N5F/[__P'(!:'KV6Z)
MA9S^___!P`4QVC'R`="+E1C___\!^`'0!:'KV6Z)A:#^___!P`7!A9C^__\>
MBY6<_O__B[V8_O__P86<_O__'C'Z,=H!T(N-G/[__P'PB[4<____BY6@_O__
MP86@_O__'@'PB[68_O__C;BAZ]EN,<J)^#'RP<`%BXV<_O__`=`!V(N=(/__
M_XN5H/[__P'8C;"AZ]EN,?J)\(N=)/___S'*P<`%BXV@_O__`="+E9C^___!
MQQX!T`'8B?*-F*'KV6XQ^HG8,<K!P`4!T(N5G/[__XN-*/___P'0`<B)VL'&
M'@6AZ]EN,?*+C2S___^)A9C^__\Q^L'`!0'0BY6@_O__P<,>`="+E9C^__\!
MR,&%F/[__QX%H>O9;HF%G/[__S':P<`%,?(!T(N5,/___P'XB[V8_O__`="+
ME9S^__\%H>O9;HF%H/[__\'`!3'ZP86<_O__'C':`=`!\(NU-/___XN-G/[_
M_XN5H/[__P'PB[68_O__C;BAZ]EN,<J)^#'RP<`%`=`!V(N=./___\&%H/[_
M_QZ+E:#^__\!V(N-G/[__XVPH>O9;HGPP<`%,?HQR@'0BY68_O__P<<>BYT\
M____BXV@_O__`=`!V(GRC9BAZ]EN,?J)V#'*P<`%BXV<_O__`="+E4#____!
MQAX!R(N-H/[__P'0B=H%H>O9;C'R,?J)A9C^___!P`4!T(N51/___\'#'@'(
MBXV8_O__P868_O__'@'0B=H)\@6AZ]EN(<J)A9S^__^)V2'Q"<K!P`4!T`'X
MB[U(____BY68_O__BXV<_O__`?@M)$/D<(F%H/[__\'`!0G:P86<_O__'B'*
MBXV8_O__B[U,____(=D)R@'0BY6<_O__`?"+M9C^__\!^(N-H/[__\&%H/[_
M_QX)\HNUF/[__R'*BXV<_O__C;C<O!N/B?@A\<'`!0G*`="+C9S^__\!V(N5
MH/[__XN=4/___PG*`=B+C:#^__^+G9S^__^-L-R\&X\A^HGPP<<>P<`%(=D)
MRHN=5/___P'0BY68_O__BXV@_O__`="+E:#^__\!V(V8W+P;CR'YB=@)^L'`
M!2'R"<J+C9S^__\!T(N56/___P'(P<8>`=")\@GZB?$M)$/D<"'YB868_O__
M(=H)RL'`!8N-H/[__P'0BY5<____P<,>`<B+C9C^__\!T(G:P868_O__'@GR
M(<J)V2TD0^1P(?&)A9S^__\)RL'`!0'0BY68_O__BXV<_O__P86<_O__'@'X
M"=J+O6#___\ARHN-F/[__P'X(=DM)$/D<(F%H/[__PG*B[UD____P<`%BXV@
M_O__`=`!\(N5G/[__XNUF/[__P'XC;C<O!N/B?C!P`4)\B'*P86@_O__'HNU
MF/[__XN-G/[__R'Q"<H!T(N-G/[__P'8BY6@_O__BYUH____"<H!V(N-H/[_
M_XVPW+P;CR'ZBYV<_O__B?#!QQ[!P`4AV0G*`="+E9C^__^+G6S___^+C:#^
M__\!T(N5H/[__P'8(?F-F-R\&X\)^HG8(?()RL'`!8N-G/[__P'0BY5P____
MP<8>`<@!T(GR"?J)\2'Y+21#Y'`AV@G*B868_O__BXV@_O__P<`%`="+E73_
M__\!R,'#'@'0+21#Y'")A9S^__^+C9C^__^)VL&%F/[__QX)\B'*B=G!P`4A
M\0G*`="+E9C^__^+C9S^__\!^(N]>/___\&%G/[__QX)VB'*BXV8_O__`?@M
M)$/D<(F%H/[__\'`!2'9"<J+C:#^__\!T,&%H/[__QX!\(N5G/[__XNUF/[_
M_XN]?/___PGR(<J+M9C^__\!^(N-G/[__XVXW+P;CXGXP<`%(?$)R@'0BXV<
M_O__`=B+78"+E:#^__\!V(VPW+P;CXN=G/[__XGPP<`%"<J+C:#^__\A^L''
M'B'9"<J+780!T(N5F/[__XN-H/[__P'0BY6@_O__`=@A^8V8W+P;CXG8"?HA
M\L'`!0G*BXV<_O__`=#!QAZ+58@!R`'0B?*)\0GZ(?DM)$/D<"':B868_O__
M"<K!P`6+C:#^__\!T,'#'HM5C`'(BXV8_O__`=")VBTD0^1PB86<_O__"?(A
MRHG9P<`%(?$)R@'0BU60`?@!T"TD0^1PB86@_O__B[V<_O__P<`%P868_O__
M'L&%G/[__QZ+E9C^__^+C9C^__\)VB'9(?H)R@'0BXV<_O__`?"+=92+E:#^
M___!A:#^__\>`?"+M9C^__^-N-R\&X\QRHGX,?+!P`6+C9S^__\!T`'8BUV8
MBY6@_O__`=B-L-;!8LHQ^HGPBUV<,<K!P`6+C:#^__\!T(N5F/[__\'''@'0
M`=B)\HV8UL%BRC'ZB=@QRL'`!0'0BY6<_O__BTV@`=`!R,'&'HM-I(G:+2H^
MG34Q\HF%F/[__S'ZP<`%`="+E:#^___!PQX!T(N5F/[__P'(P868_O__'BTJ
M/ITUB86<_O__,=K!P`4Q\@'0BU6H`?B+O9C^__\!T(N5G/[__RTJ/ITUB86@
M_O__P<`%,?HQV@'0`?"+=:S!A9S^__\>BY6@_O__BXV<_O__`?"+M9C^__^-
MN-;!8LHQRHGXP<`%,?*+C9S^__\!T`'8BUVP`=C!A:#^__\>C;#6P6+*BUVT
MB?"+E:#^___!P`4Q^C'*BXV@_O__`="+E9C^___!QQX!T`'8B?*-F-;!8LHQ
M^HG8,<K!P`6+3;@!T(N5G/[__\'&'@'0`<B)VBTJ/ITU,?*+3;R)A9C^__\Q
M^L'`!0'0BY6@_O__P<,>`="+E9C^__\!R,&%F/[__QXM*CZ=-8F%G/[__S':
MP<`%,?(!T(M5P`'XB[V8_O__`="+E9S^__\M*CZ=-8F%H/[__\'`!3'ZP86<
M_O__'C':`=`!\(MUQ(N5H/[__\&%H/[__QZ+C9S^__\!\(NUF/[__XVXUL%B
MRHGX,<K!P`4Q\@'0BY6@_O__`=B+7<B+C9S^__\Q^L'''@'8C;#6P6+*B?`Q
MRHM=S,'`!8N-H/[__P'0BY68_O__`=`!V(V8UL%BRHGR,?J)V#'*BTW0P<`%
M`="+E9S^___!QAX!T`'(B=HM*CZ=-3'RB868_O__,?K!P`4!T(N5H/[__XM-
MU`'0BY68_O__`<C!A9C^__\>+2H^G37!PQZ)A9S^__\QVC'RP<`%`="+5=@!
M^(N]F/[__P'0BY6<_O__+2H^G36)A:#^___!P`4Q^L&%G/[__QXQV@'0`?"+
M==R+E:#^___!A:#^__\>BXV<_O__`?"+M9C^__^-N-;!8LJ)^#'*P<`%,?(!
MT(N-G/[__P'8BUW@`=B-L-;!8LJ+A:#^__^)\HN=F/[__\'"!3'X,<B+3>0!
MPL'''@':`<J+C:3^__\!<02+`0%Y"(V4`M;!8LJ)$8N%H/[__P%!#(N5G/[_
M_P%1$('$7`$``%M>7UW#B?:-O"<`````53'`B>5=PXGVC;PG`````%6)Y8/L
M*(E=](EU^(E]_(G'QT7P`````.B3&0``B00DZ#L9``")QNB$&0``B00DZ#P9
M``")P^AU&0``B00DZ"T9``"+$(ET)`B)?"0$BP.)!"3_4E"%P'07BT7PBUWT
MBW7XBWW\B>Q=PXVT)@````#H.QD``(D$).CC&```#[=`!B4`\```/0!```!U
MS.@>&0``B00DZ-88``")P^@/&0``B00DO@(```#HPA@``(L0B70D"(E\)`2+
M`XD$)/\2A<!UEL=%\`$```#KC8UT)@!5B>57ORQA0`!64X/L;#';@#TL84``
M`,=%R"QA0`#'1<P\84``QT701&%``,=%U%%A0`#'1=A684``QT7<:&%``'1*
MC;8`````C;PG`````(GXZ&GF__^%P(G&=`6`.`!U#HM5"(GXZ&3F___K%6:0
MB30DBT4(B40D!.CA&0``A<!T$D.+?)W(@#\`=<.#Q&Q;7E]=PXM5"(D4).C@
M&0``B47`H0100`")!"3HT!D``(DT)(M5P`'0B46\Z,`9``"+3;R-1`$"B46X
MZ!$8``")!"3HV1<``(E%M.@!&```B00DZ,D7``"+$(M%N(M-M(E$)`2+`8D$
M)/\2B70D$(E%Q*$$4$``BU7$B40D#(M%"(D4)(E$)`BX5V!``(E$)`3H"QD`
M`(M5Q.DX____C78`5;@\@0``B>575E/H\!X``,=%V&EA0``QP(F%\'[__[@_
M8$``QT7<`&!``,=%X%5@0`#'1>1H84``QT6X\V!``,=%O'%A0`#'1<!X84``
MQT7$@&%``,=%R(5A0`#'1<QH84``QT6HB6%``,=%K(YA0`#'1;!H84``Z!/E
M__^%P(G'=`F`.``/A0@$``"X!`$``(F%]'[__^@4%P``B00DZ-P6``")P^@%
M%P``B00DZ,T6``"+$+@$`0``B40D!(L#B00D_Q*)A>Q^__^-A?1^__^)1"0$
MBX7L?O__B00DZ/T8``"#[`CH!?W__XF%['[__X7`#X0!!```BYWL?O__#[8#
MA,!T.HUV`(V\)P`````/OM"A4-)``(,X`0^%0`,``*&0TD``BP`/MP10)0<!
M``"%P'4#Q@-?0P^V`X3`=="+1;@QVX`X`'0RC;8`````Z#OD__^%P(G'=`WH
MH/S__X7`#X4/`P``B[7P?O__0X7V=7F+1)VX@#@`==2XEV%``.@*Y/__A<")
MQW1@B00DZ+P7``"-<`;H%!8``(D$).C<%0``B</H!18``(D$).C-%0``BQ")
M="0$BP.[GF%``(D$)/\2B7PD"(E<)`2)QHD$).@I%P``B?#H(OS__X7`#X1=
M`P``B;7P?O__BXWP?O__,=N%R0^$L`(``(N5\'[__XD4).A&%P``QP0DIF%`
M`(G#Z#@7```!PXN%['[__XD$).@H%P``QP0D:&%```'#Z!H7``"-M`,`!```
MZ&X5``")!"3H-A4``(G#Z%\5``")!"3H)Q4``(L0B70D!(L#B00D_Q*+E>Q^
M__^)A>A^__^XIF%``(E4)!2)1"00H0!00`")1"0,BX7P?O__B40D"+BK84``
MB40D!(N5Z'[__XD4).A7%@``BX7H?O__B00DZ`D6``"X46%``.C/XO__A<`/
MA,$!``")!"3HGQ8``(E$)`2+50B+`HD$).A>Y?__A<")Q@^$G@$``.@?ZO__
MA<!U0>BV%```B00DZ&X4``")P^BG%```B00DZ%\4``"+$+@`@```B40D"(ET
M)`2+`XD$)/]2/(F%Y'[__X7`#X4\`@``BY7H?O__,?:)%"3H"A8``(G'N@YA
M0`"XGF!``.A)XO__Z%04``")!"3H[!,``(G#Z$44``")!"3HW1,``(L0BP.)
M!"3_4FBY:&%``+JT84``B4PD%(E$)!"A`%!``(E$)`R+A>A^__^)5"0$B40D
M"(D$).A2%0``ZW#H^Q0``(,X$75[BY7H?O__1L8$%P#HYA,``(D$).A^$P``
MB</HUQ,``(D$).AO$P``BQ"+`[MH84``B00D_U)HB5PD&+G"84``B70D%(E$
M)!"A`%!``(E$)`R+A>A^__^)3"0$B40D"(D$).C@%```BY7H?O__B10DZ)(4
M``!`#X1[____BY7H?O__N#]@0`#H6^'__XN%Z'[__XD$).A]^O__BX7H?O__
MC67T6UY?7<.)%"2_!P$``(E\)`3H[A0``.FZ_/__B3PDZ/$4``")A?!^___I
MWOS__XM%"(LPZ5C^__^)!"3H-/K__XD\).C,%```C67T6UY?7<.+?=B`/P`/
MA$3]__^)^.A!^?__A<!U)XN5\'[__T.%T@^%*OW__XM\G=B`/P`/A!W]__^)
M^.@:^?__A<!TV8D\).A^%```B87P?O__Z\F+1:@QVX`X`'0OZ(?@__^%P'0.
MB00DZ%L4``")A>Q^__^+A>Q^__]#A<`/A<_[__^+1)VH@#@`==&XTV%``(F%
M['[__^G]^___Z&@2``")!"3H,!(``(G#Z%D2``")!"3H(1(``(L0B70D!(L#
MB00D_U((Z7K\___H.1(``(D$)+\&````Z.P1``")P^@E$@``B00DZ-T1``"+
M$+@"````B40D$+CN____B40D"+C_____B40D#(N%Y'[__XE$)`2+`XD$)/]2
M,.CI$0``B00DZ*$1``")P^C:$0``B00DZ)(1``"+$(V%&'___XE\)`R)1"0(
MBX7D?O__B40D!(L#B00D_U)$@+T8?___`'4-@+T9?___0P^$$P0``+@!(T5G
MOW94,A"^\.'2PXF%&/___[B)J\WO,=N)A1S___\QR;C^W+J8B84@____,=*)
MO23___^)M2C___^)G2S___^)C3#___^)E73___^-="8`C;PG`````.@[$0``
MB00DZ/,0``")P^@L$0``B00DZ.00``"+$+@`@```B40D#(V%&'___XE$)`B+
MA>1^__^)1"0$BP.)!"3_4D2%P(G'#X[_````C948?___BX4P____B?N)E>!^
M__^+E2S___^-#/J)C2S___\YT8/0`(F%,/___XGXP>@=`84P____BX5T____
MA<!T7KY`````*<8Y_GX"B?Z)="0(C80H-/___XG[B00DC948?___*?.)5"0$
MZ+(1``"-A1A___\!\(F%X'[__XN%=/___P'PB85T____@_A`#X4=____C848
M____Z`+F__^-O33____K,+A`````@^M`B40D"(N5X'[__XD\)(E4)`3H7!$`
M`(.%X'[__T"-A1C____HRN7__X/[/W_+B5PD"(N%X'[__XD\)(E$)`3H+Q$`
M`(F==/___^FT_O__Z.\/``")!"3HIP\``(G#Z.`/``")!"3HF`\``(L0BX7D
M?O__B40D!(L#C9WX?O__B00D_U(0BY4L____L("+M3#___^)E=Q^___!Z@.#
MXC^(A"HT____0H/Z.`^.YP$``+A`````C;TT____*=")1"0(C905-/___S'`
MB10DB40D!.B-$```C848____Z!+E___\N0X````QP/.K#[:5W'[__XGPP>@8
MB(5L____B?#!Z!"(A6W___^)\,'H"(B%;O___XGPC;5X____B(5O____BX7<
M?O__B?>(E7/____!Z!B(A7#___^+A=Q^___!Z!"(A7'___^+A=Q^___!Z`B(
MA7+___^-A1C____HDN3__XN5&/___XG0P>@8B`.)T,'H$(A#`8G0P>@(B$,"
MB%,#BY4<____B="(4P?!Z!B(0P2)T,'H$(A#!8G0P>@(B$,&BY4@____B="(
M4PO!Z!B(0PB)T,'H$(A#"8G0P>@(B$,*BY4D____B="(4P_!Z!B(0PR)T,'H
M$(A##8G0P>@(B$,.BY4H____B="(4Q/!Z!B(0Q")T,'H$(A#$8G0P>@(B$,2
M,=N-M@````"-OP`````/MH0K^'[__T.)/"2#QP*)1"0(N-IA0`")1"0$Z%\/
M``"#^Q-^VL9%H`"_:&%``(E\)!2)="00H0!00`"[WV%``(E$)`R+A>A^__^)
M7"0$B40D"(D$).@E#P``BY7H?O__N#]@0`#HM=O__XN%Z'[__XD$).C7]/__
MBX7H?O__Z57Z__^X.````"G0C905-/___XE$)`@QP(E$)`2)%"3HK`X``.DO
M_O__@+T:?___00^%X/O__X"]&W___T,/A=/[__^`O1Q___](#X7&^___@+T=
M?___10^%N?O__^A.#0``B00DO@(```#H`0T``(G#Z#H-``")!"3H\@P``(L0
MN<;___^X_____XE,)`B)="00B40D#(N%Y'[__XE$)`2+`XD$)/]2,.@##0``
MB00DZ+L,``")P^CT#```B00DZ*P,``"+$+@I````B40D#(V%&'___XE$)`B+
MA>1^__^)1"0$BP.)!"3_4D2X:&%``(V5&'___XE$)!2)5"00Z;3^__^-M@``
M``"-O"<`````58GE5U93@>Q,`0``A<")A<3^__]T!8`X`'4(C67T6UY?7<.)
M!"3H%0X``(VP`@$``.AJ#```B00DZ#(,``")P^A;#```B00DZ",,``"+$(ET
M)`2+`[ON84``B00D_Q*)A<#^__^+A<3^__^)7"0$B40D"(N-P/[__XD,).AO
M#0``C87(_O__B40D!(N-P/[__XD,).CW#```B86\_O__0`^$=?___[E<````
MC87<_O__B4PD!(D$).B##```A<`/A88```"-="8`C;PG`````(V-W/[__[KU
M84``B4PD#(N%Q/[__XE4)`2)1"0(BXW`_O__B0PDZ/4,``#K9HUV`(N%P/[_
M_^CU_O__D(UT)@"-A<C^__^)1"0$BXV\_O__B0PDZ$@,``"%P`^%Z````+E<
M````C87<_O__B4PD!(D$).CY"P``A<!TA8V%W/[__XE$)`2+C<#^__^)#"3H
MS0L``+C[84``B40D!(N%P/[__XD$).BF#```A<")PW0K_(G&N`,```"_^V%`
M`(G!\Z8/A'G___^)WK_^84``N00```#SI@^$9?____:%R/[__Q`/A4C___^-
MA=S^__\QVXD$).CH#```@^P$B<:-=@"+C<#^__^)#"3HH@L``(7`#X0J____
MB=A#@_@)#X\>____A?9TVHDT).BB#```BXW`_O__@^P$B0PDZ'$+``"%P'73
MZ?C^__^+A;S^__^)!"3H.@L``(N-Q/[__XD,).@<"P``C67T6UY?7<.-="8`
M58GE@^P8B5WXBUT(B77\B1PDZ&G=__^)!"3H$=W__XG&Z)K?__^%P'0FA=MT
M(H`[`'0=B30DN*9A0`")1"0$Z)P+```Y\'02D(VT)@````"+7?B+=?R)[%W#
MBW7\B=B+7?B)[%WI5OW__XVV`````%6)Y5.#[!3HY`D``(D$).AL"0``BP"+
M6`3HT@D``(D$).A*"0``#[8`B$,8Z+\)``")!"3H1PD``(L`BU@$Z*T)``")
M!"3H%0D``(L`#[=`$"7_`0``9HE#&NB1"0``B00DZ!D)``"+`(M8!.A_"0``
MB00D,<FZ:&%``(E4)`2)3"0(Z,@(``")0QSH8`D``(D$).CH"```BP"+6`3H
M3@D``(D$).B6"```BP")0R#H/`D``(D$).C$"```BP"+6`3H*@D``(D$).AB
M"```BP`QTH7`=5^)4R3H$@D``(D$).B:"```BP"+0`3'0"@`````Z/D(``")
M!"3H@0@``(L`BT`$QT`L`````.C@"```B00DZ&@(``"+`(M8!.C."```B00D
MZ/8'``"+`(E#,(/$%%M=P^BV"```B00DZ.X'``"+`(M0;.N-C;0F`````%6)
MY8/L&.B5"```B00DNO____^)5"0$Z*0'``#H?P@``(D$)#')ND`\0`")3"0(
MB50D!.AX!P``R<.-M@````!5B>57,?]64X/L'.A0"```B00DZ$@'``#&``&X
M@F!``.@;UO__A<!T"8`X,0^$#@(``.@YW/__Z"0(``")!"2Y"P```+H!````
MB4PD#+X"8D``B50D"(ET)`3H\08``(7`#X2&````BT`,O@$```"+%5#!0`"+
M0!@YUHE%\'UCD.C;!P``B00DC5;_,=N)5"0(BU7PB5PD#(E4)`3HGP8``(7`
MB<,/A(8"``"+`/9`"00/A)D!``"+0`R)1"0$H6#!0`"+!+")!"3H\@@``(7`
M#X5;`@``1T:+%5#!0``YUGR>C4+_.?@/A*,!``#H;@<``(D$)+L!````N0=B
M0`")7"0(O@4```")="0,B4PD!.@[!@``A<")PW0NZ$`'``"Z"6)``(E4)`B+
M4PR+$HD$)(E4)`3HU@4``(M##(L`]D`*0`^%S0$``.@2!P``B00DNQ)B0`"_
M!0```(E<)`2^`0```(E\)`R)="0(Z-\%``"%P(G#="ZX2&!``.B_U/__A<")
MQ@^$-P$``.C0!@``B70D"(M3#(L2B00DB50D!.AK!0``Z+8&``")!"3HK@4`
M`,8``.BF!@``B00DZ"X%``#'``````"X/V!``.ANU/__HT#!0`"%P`^$F```
M`.A\!@``B00DZ/0$``")P^AM!@``B00DZ.4$``"+$+GM`0``H4#!0`")3"0(
MB40D!(L#B00D_Q*%P(G&#Y7",<"#_A$/E<"%PG0)@_[_#X4@`0``@\0<6UY?
M7<.-M@````"`>`$`#X3M_?__Z>/]__^0Z`L&```QTKD"````B4PD#(E4)`B+
M$XD$)(E4)`3HO@0``.E#_O__H6#!0`")!"3H+.[__Z-`P4``Z5'___]FD+X!
M````.=8/C5#^__^-=@#HNP4``(D$)(M5\$:)5"0$Z&L$```[-5#!0`!\X^DK
M_O__Z!G6__^%P(G&=&_HC@4``(ET)`B+4PR+$HD$)(E4)`3H*00``.AT!0``
MB00DZ#P%``")P^AE!0``B00DZ"T%``"+$(ET)`2+`XD$)/]2".F/_O__Z$4%
M``"+4PR+$HD$)(E4)`3HU`,``.D8_O__BQ50P4``Z:;]___H'P4``(L58,%`
M`(L2B50D".E"_O__B70D#*%`P4``B40D"*%@P4``BP#'!"048D``B40D!.A:
M`P``C78`C;PG`````%6)Y8/L&.C5!```B00DZ(W1___HR`0``(D$)#'2N6AA
M0`")5"04NFAA0`")3"00N=`]0`")5"0,NF)B0`")3"0(B50D!.CV`@``R<.-
M="8`5;@0````B>575E.#[!R#Y/#HR@L``.A%!P``C440B40D"(U%#(E$)`2-
M10B)!"3HK`(``,<$)`````#HD`(``(`X`'4JZ'8"``"C,,%``(7`#X2"`0``
MB00DZ%$"``#H+`0``(D$).@T`@``Q@``Z!P$``")!"3H%`(``(`(`N@,!```
MB00DZ`0"``"`"`$QTE+=!8!B0`"+30B-0050WRPD@\0(W`6(8D``VNG?X)X/
MAU(!``"-!(T4````O@$```")!"3HM@$``*-@P4``BWT,B<.+!\=#!'=B0`#'
M0PB08D``B0.X!````,=##'IB0`"+30BC4,%``#G.?`OK)HL=8,%``(M]#(L5
M4,%``(L$MP'RB423_$:+30@YSGS@BQU@P4``H5#!0``Q_S'V`<&)?(O\H6#!
M0`"Y4$%``(ET)!"+70B)3"0$B40D#*%0P4```=A(B40D"*$PP4``B00DZ`D!
M``"%P(G#=%NA,,%``(D$).C6````N))@0`#H[-#__X7`=22A0,%``(7`=1.X
M/V!``.C5T/__HT#!0`"%P'0(B00DZ(3X__^A,,%``(D$).B'````Z'(```"-
M9?2)V%M>7UW#H3#!0`")!"3HBP```(G#ZY3HL@(``(D$).A*`@``B</HHP(`
M`(D$).@[`@``BQ"X`0```(E$)`2+`XD$)/]2"*'HTD``B00DZ.L```"0D)"0
MD)"0D)"0D/\EZ-)``)"0``````````#_)6C30`"0D```````````_R6`TT``
MD)```````````/\E?--``)"0``````````#_)8C30`"0D```````````_R6$
MTT``D)```````````/\E5--``)"0``````````#_)0S30`"0D```````````
M_R4<TT``D)```````````/\E>--``)"0``````````#_)7330`"0D```````
M````_R7LTD``D)```````````/\E9--``)"0``````````#_)5#30`"0D```
M````````_R4TTT``D)```````````/\E\-)``)"0``````````#_)0#30`"0
MD```````````_R5$TT``D)```````````/\E8--``)"0``````````#_)3#3
M0`"0D```````````_R5<TT``D)```````````/\E+--``)"0``````````#_
M)4#30`"0D```````````_R4DTT``D)```````````/\E6--``)"0````````
M``#_)3C30`"0D```````````_R4HTT``D)```````````/\E&--``)"0````
M``````#_)0C30`"0D```````````_R5(TT``D)```````````/\E%--``)"0
M``````````#_)1#30`"0D```````````_R4$TT``D)```````````/\E_-)`
M`)"0``````````#_)2#30`"0D```````````_R7TTD``D)```````````/\E
M^-)``)"0``````````#_)7#30`"0D```````````_R5LTT``D)``````````
M`/\E/--``)"0``````````#_)4S30`"0D```````````_R5<TD``D)``````
M`````/\E9-)``)"0``````````#_)5320`"0D```````````_R6\TD``D)``
M`````````/\E6-)``)"0``````````#_)9C20`"0D```````````_R5,TD``
MD)```````````/\ES-)``)"0``````````#_)<320`"0D```````````_R64
MTD``D)```````````/\E;-)``)"0``````````#_)7320`"0D```````````
M_R6<TD``D)```````````/\E<-)``)"0``````````#_)6C20`"0D```````
M````_R6(TD``D)```````````/\EN-)``)"0``````````#_);#20`"0D```
M````````_R74TD``D)```````````/\EP-)``)"0``````````#_)<C20`"0
MD```````````_R7<TD``D)```````````/\EV-)``)"0``````````#_);32
M0`"0D```````````_R70TD``D)```````````/\EA-)``)"0``````````#_
M)3S20`"0D```````````_R5`TD``D)```````````/\E,-)``)"0````````
M``#_)1C20`"0D```````````_R4@TD``D)```````````/\E+-)``)"0````
M``````#_)2C20`"0D```````````_R4(TD``D)```````````%6)Y8/L"*%`
M4$``@S@`=!?_$(L50%!``(U"!(M2!*-`4$``A=)UZ<G#C;0F`````%6)Y5.#
M[`2A,$Y``(/X_W0IA<")PW03B?:-O"<`````_Q2=,$Y``$MU]L<$)'!(0`#H
MZLG__UE;7<,QP(,]-$Y```#K"D"+'(4T3D``A=MU].N^C;8`````C;PG````
M`%6A@,%``(GEA<!T!%W#9I!=N`$```"C@,%``.N#D)"05;G0O$``B>7K%(VV
M`````(M1!(L!@\$(`8(``$``@?G0O$``<NI=PY"0D)"0D)"058GE4YR<6(G#
M-0``(`!0G9Q8G3'8J0``(``/A,`````QP`^BA<`/A+0```"X`0````^B]L8!
M#X6G````B=`E`(```&:%P'0'@PV0P4```O?"``"``'0'@PV0P4``!/?"````
M`70'@PV0P4``"/?"`````G0'@PV0P4``$('B````!'0'@PV0P4``(/;!`70'
M@PV0P4``0/;%('0*@0V0P4``@````+@```"`#Z(]````@'8LN`$``(`/HJ&0
MP4``B<&!R0`!``"!X@```$!T'PT``P``HY#!0`"-M@````!;7<.##9#!0``!
MZ4W___];B0V0P4``7<.0D)"0D)"0D%6)Y=OC7<.0D)"0D)"0D)!5H0#"0`")
MY5V+2`3_X8GV5;I"````B>53#[?`@^QDB50D"(U5J#';B50D!(D$)/\5)-)`
M`+H?````N0$```"#[`R%P'4'ZST!R4IX#H!\*JA!=?0)RP')2GGR@SM4=0>)
MV(M=_,G#QP0D-+Q``+KW````N&2\0`")5"0(B40D!.C+`@``QP0DF+Q``+OQ
M````N62\0`")7"0(B4PD!.BM`@``C;8`````C;PG`````%6)Y5=64X'LO```
M`(L]`,)``(7_=`B-9?1;7E]=P\=%F$%!04&A$+Q``(U]F,=%G$%!04''1:!!
M04%!B46XH12\0`#'1:1!04%!QT6H04%!08E%O*$8O$``QT6L04%!0<=%L$%!
M04&)1<"A'+Q``,=%M$%!04&)1<2A(+Q``(E%R*$DO$``B47,H2B\0`")1="A
M++Q``(E%U`^W!3"\0`!FB478B3PD_Q4<TD``#[?`@^P$A<`/A7$!``#'!"14
M````Z/D!``"%P(G##X2/`0``B00D,<F^5````(E,)`2)="0(Z%C[___'0P3@
M34``N0$```#'0PA@2D``H;#!0`#'`U0```"+%;3!0`#'0R@`````B4,4H5!0
M0`")4QB+%5100`")0QRAP,%``,=#+/____^)4R")0S"A6%!``(L57%!``(E#
M-*'0P4``B5,XBQ74P4``B4,\H>#!0`#'0T3_____B5-`B4-(BQ5D4$``H6!0
M0`")4U"Z'P```(E#3(G8(<B#^`$9P"0@`<D$08B$*DC___]*>>>A$+Q``(F%
M:/___Z$4O$``B85L____H1B\0`")A7#___^A'+Q``(F%=/___Z$@O$``B85X
M____H22\0`")A7S___^A*+Q``(E%@*$LO$``B46$#[<%,+Q``&:)18B-A4C_
M__^)!"3_%1320``/M_"#[`2%]G5",=*%TG4>B1PDZ),```")/"3_%1S20`"#
M[`0/M\#H+_W__XG#B1T`PD``C4,$H_#!0`"-0PBC$,)``(UE]%M>7UW#B?#H
M"/W__SG8B?)UL>NQZ&L```"0D)"0D)"0D)"0D%&)X8/!"#T`$```<A"!Z0`0
M``"#"0`M`!```.OI*<&#"0")X(G,BPB+0`3_X)"0D/\E8-)``)"0````````
M``#_):C20`"0D```````````_R6LTD``D)```````````/\EH-)``)"0````
M``````#_)2320`"0D```````````_R4<TD``D)```````````/\E%-)``)"0
M``````````!5B>5=Z;?$__^0D)"0D)"0_____R!.0```````_____P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````8$```F!`
M`/____\`````;5D``/Z[0````````````/____\`````````````````0```
M````````````````0$Y```````````````````````#_____`````/____\`
M````_____P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````%P`.P!P97)L>'-I+F,`1'EN84QO861E<CHZ8F]O=%]$>6YA
M3&]A9&5R`%=I;C,R0T]213HZ8F]O='-T<F%P`%!!4E]414U0`%!!4E]04D]'
M3D%-10`N`"5S)7,E<P```%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!
M4E]$14)51P!005)?0T%#2$4`4$%27T%21T,`4$%27T%21U9?,`!005)?1TQ/
M0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,
M3T)!3%]414U0`#$`4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`$Q$7TQ)
M0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42`!0051(`$193$1?3$E"
M4D%265]0051(``!#.EQ414U0`%1-4$1)4@!414U01$E2`%1%35``5$U0`%53
M15(`55-%4DY!344`5VEN1&ER`"5S7'1E;7``<&%R+0`E<R5S)7,E<P`E<R5S
M=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`4UE35$5-`"4P,G@`)7,E<V-A
M8VAE+25S)7,`)7-<*BXJ`"5S7"5S`%PN`%PN+@!!4D=6`!@`<&5R;"YE>&4`
M,``E<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@!);G1E<FYA;',Z
M.E!!4CHZ0D]/5``M90`M+0```````(#____/00``````````(R$O=7-R+V)I
M;B]P97)L"@IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB
M)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L
M;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@
M;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E
M('-T<FEC=#L*"B-L:6YE(#$U.0H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE
M+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@
M(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA
M;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H
M<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z
M.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN
M:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$
M;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E
M('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A
M<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G
M*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@
M=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I
M8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI
M;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B
M;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD
M"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@
M;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG
M="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P
M<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T
M:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*
M("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@
M("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@
M("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)
M3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B
M:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F
M("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE
M;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD
M>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@
M("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@
M;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@
M)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D[
M"B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T
M;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL
M96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@
M("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[
M4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'
M5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!
M4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@
M>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD
M7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.
M5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O
M;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/
M(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^
M("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G
M)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T
M96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN
M9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P
M;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@
M("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO
M;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@
M("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@("!S965K(%]&2"P@
M+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S
M("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#([
M"B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U
M;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*
M("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@
M("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@
M;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@
M>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN
M86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D
M9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE
M(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@
M("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@
M("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@
M("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\
M:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I
M(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U
M="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@
M("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E
M("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@
M("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL
M:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@
M("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@
M("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E
M>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*
M("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D
M:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@
M('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@
M("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1R97%U:7)E7VQI
M<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^
M("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@
M("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@("`@
M("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@
M?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D
M=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE
M=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@
M(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?
M;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L
M95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME
M>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@
M("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D
M=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE
M9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN
M;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[
M8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@
M("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I
M;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@
M("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I
M;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO
M<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F
M:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H
M)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@
M("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M
M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@
M8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B
M:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q
M=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@
M(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG
M(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&
M:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?
M7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD
M9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@
M("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F
M:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI
M('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3
M:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@
M("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@
M+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@
M('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P
M,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@
M?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*)'%U
M:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PH*(R!$;VXG="!S=V%L
M;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U
M="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?
M8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@
M(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@
M("!S("`@<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*
M"B`@("!M>2!`861D7W1O7VEN8SL*("`@('=H:6QE("A`05)'5BD@>PH@("`@
M("`@("1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["@H@("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@
M<'5S:"!`861D7W1O7VEN8RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF
M("@D,2!E<2`G32<I('L*("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@
M("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@
M("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L
M<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@)&]U="`]("0R.PH@("`@
M("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@
M("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D
M,2!E<2`G0B<I('L*("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@
M("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@
M("1Q=6EE="`](#$["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G
M3"<I('L*("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("!]"B`@("`@
M("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`D8V%C:&5?;F%M
M92`]("0R.PH@("`@("`@('T*"B`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@
M("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@
M("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@(&EN:71?
M:6YC*"D["B`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@
M("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@
M("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*
M("`@("`@("`@("`@97AI=#L*("`@("`@("!]"B`@("!]"@H@("`@=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0H*(R!86%@@+2T@861D("TM<&%R+61E
M8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L
M:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#
M>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@
M("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI
M=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PH@
M("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@
M(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G
M)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@("`@
M("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@?0H*
M"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M>2`D
M;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@("`@
M("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D;65T
M82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@("A;
M7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@(R!/<&5N
M(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`](%PT
M.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!4BP@
M)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO9&4H
M4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N
M;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E871E
M4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I('P@
M24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`H@
M("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H
M*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S
M(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D97(@
M/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@?0H@
M("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@("`@
M(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A;"`]
M(&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@)&UA
M9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@("`@
M(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@("`@
M("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D;6%G
M:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I
M*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D97(I
M.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B=6YD
M;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@(')E
M<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*"B`@("`@("`@<F5Q
M=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@
M("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@
M9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"![
M"B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@
M("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@
M("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"B`@("`@("`@?2!`24Y#.PH*("`@("`@("!I9B`H)$-O;F9I9WM?9&5L:6U]
M(&5Q("=<7"<I('L@<WM<7'U[+WUG(&9O<B!`:6YC('T*"B`@("`@("`@(R!&
M:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O(&9I>"!25"`C-#$W.3`Z"B`@("`@
M("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG(&5N=')Y(&EN(%\\+BXN+F%U=&\O
M0V]M<')E<W,O4F%W+UIL:6(O875T;W-P;&ET+FEX+@H@("`@("`@(",@5&AI
M<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O9B!T
M:&4@:7-S=64N"B`@("`@("`@(R!3;VUE8F]D>2!P;&5A<V4@9V\@=&AR;W5G
M:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD:6YG('=H870G<R!H87!P96YI;F<L
M"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@4W1E9F9E;@H@("`@("`@(&UY("5F
M:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S
M>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@("`@("`D9FEL97-[)%]]*RL@9F]R
M('9A;'5E<R`E24Y#.PH*("`@("`@("!M>2`D;&EB7V5X="`]("1#;VYF:6<Z
M.D-O;F9I9WML:6)?97AT?3L*("`@("`@("!M>2`E=W)I='1E;CL*"B`@("`@
M("`@9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PH@("`@("`@("`@("!M
M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@("`@("`@(&9O<F5A8V@@;7D@)&1I
M<B`H0&EN8RD@>PH@("`@("`@("`@("`@("`@:68@*"1N86UE(#T@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@("`@("`@("`@("`@("`@("`D
M9FEL92`]("1?.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<
M+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@("`@("`@("`@("`@("`@*"1F:6QE
M+"`D;F%M92D@/2`H)#$L("0R*3L*("`@("`@("`@("`@("`@("`@("!L87-T
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*&TA
M7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[
M)#%]*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I
M(#T@*"1R968L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@96QS
M:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`H
M)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&YE>'0@
M=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK
M*SL*("`@("`@("`@("`@;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@("`@("`@(&]U=',H(&IO:6X@
M(B(L"B`@("`@("`@("`@("`@("!Q<2A086-K:6YG("(I+"!R968@)&9I;&4@
M/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"B`@("`@("`@("`@("`@("!Q<2@B
M+BXN*0H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@;7D@)&-O;G1E;G0[
M"B`@("`@("`@("`@(&EF("AR968H)&9I;&4I*2!["B`@("`@("`@("`@("`@
M("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&]P96X@1DE,12P@)SPG
M+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@("`@
M("`@("`@("`@(&)I;FUO9&4H1DE,12D["B`@("`@("`@("`@("`@("`D8V]N
M=&5N="`](#Q&24Q%/CL*("`@("`@("`@("`@("`@(&-L;W-E($9)3$4["@H@
M("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@:68@
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\
M86PI)"]I.PH*("`@("`@("`@("`@("`@(",@1&\@;F]T(&QE="!84TQO861E
M<B!P:6-K('5P(&%U=&\O*B!F<F]M(&5N=FER;VYM96YT"B`@("`@("`@("`@
M("`@("`D8V]N=&5N="`]?B!S+V=O=&\@*W)E=')Y("MU;FQE<W,@*RXJ+V=O
M=&\@<F5T<GD[+PH@("`@("`@("`@("`@("`@("`@(&EF(&QC*"1N86UE*2!E
M<2!L8R@B6%-,;V%D97(N<&TB*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@
M)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A
M8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M
M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R
M8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@
M("`@("`@("`@*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D
M8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO
M=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@
M("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D
M8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I
M9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;
M.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W
M('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O
M<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY
M("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@
M?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^
M861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@
M("`@96QS92!["B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F
M:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*
M("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@
M("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z
M("1M=&EM93L*("`@('T*("`@("1C86-H95]N86UE("X](")<,"(@>"`H-#$@
M+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!
M0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D[
M"B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E
M.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*
M?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A
M8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,[
M"@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!
M4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@
M<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["@H*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?
M7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@
M1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@
M('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F
M:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(
M*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H
M92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP
M.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q
M*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@
M870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D
M>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@("!N97AT(&EF("1M96UB97(M
M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D
M;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@("`@("`@("`@
M("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N
M9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@
M("`@("`@("`@("`@("`D"B`@("`@("`@("`@('UX.PH@("`@("`@("`@("!M
M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA
M;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT
M<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@*"UF("1D97-T7VYA;64@)B8@
M+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@("`@
M("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN
M8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X=')A
M8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@("`@
M("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?
M;F%M92D["B`@("`@("`@("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N86UE
M*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN
M<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6
M.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L
M92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"
M?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]
M?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@
M"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M
M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D
M;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@[
M"B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&
M24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*
M("`@(')E<75I<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*
M("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@
M(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@
M0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@<F5Q
M=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I
M<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U
M:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E<75I
M<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@("`@
M<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@(')E
M<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!E=F%L('L@<F5Q
M=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R('T["B`@("!E
M=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R97%U
M:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*?0H*(R!4:&4@0R!V97)S
M:6]N(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*
M(R!4:&ES(&-O9&4@86QS;R!L:79E<R!I;B!005(Z.E-E='5P5&5M<"!A<R!S
M971?<&%R7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T
M=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM
M87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%
M35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@
M*2!["B`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@
M)'!A=&@@86YD("UW("1P871H.PH@("`@("`@(&UY("1U<V5R;F%M93L*("`@
M("`@("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y
M=VAE<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@
M:68@9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*&1E9FEN
M960@)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1P=W5I9#L*
M("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1U<V5R;F%M
M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<[
M"B`@("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@
M("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M
M)'5S97)N86UE(CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@
M("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H
M+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L
M(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@
M("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@("`@("`@("`@
M("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@("!S>7-R96%D
M("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O
M+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96QS92!["B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@
M("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@
M1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T[
M"@H@("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG
M97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H
M85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\
M(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X
M)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@
M("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B
M/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&)I;FUO
M9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL
M92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q
M.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M
M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S
M=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@
M(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T
M96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D
M9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D
M8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@
M('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U
M<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@
M("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M
M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I
M92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE
M;F%M92D["GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G
M;F%M93HZ<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF
M("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/
M1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@
M("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%2
M7U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^
M/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@
M<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@
M?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P
M96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R971U
M<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G
M;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N
M/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I
M9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF
M(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]4
M14U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O
M+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I
M9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X
M97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P
M<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/
M1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA
M:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN
M960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I
M.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<
M+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*
M"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?
M<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@("`@
M("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R
M("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%
M($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G
M+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?
M1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]]
M.PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@
M>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E
M;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@
M("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H
M*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D
M=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T
M<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@
M("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*
M("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R![
M"B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I
M;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C
M:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@
M("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F
M;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L
M('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R
M>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*
M0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*
M?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*
M,3L*"B-L:6YE(#$P,#(*"E]?14Y$7U\*`'!A<BYP;````````````````"U,
M24)'0T-7,S(M14@M,RU32DQ*+4=42%(M34E.1U<S,@```'<S,E]S:&%R961P
M='(M/G-I>F4@/3T@<VEZ96]F*%<S,E]%2%]32$%2140I`````"XN+RXN+V=C
M8RTS+C0N-2]G8V,O8V]N9FEG+VDS.#8O=S,R+7-H87)E9"UP='(N8P````!'
M971!=&]M3F%M94$@*&%T;VTL(',L('-I>F5O9BAS*2D@(3T@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!\
MT``````````````XV0``"-(``(C0`````````````&C9```4T@``L-``````
M````````@-D``#S2``#`T``````````````@V@``3-(``%S1````````````
M`-#:``#HT@``````````````````````````````````D-,`````````````
MH-,``*S3``"\TP``R-,``-C3``#HTP```-0``!34`````````````#34``!`
MU`````````````!,U```7-0``&S4``!\U```C-0``*#4``"LU```N-0``,34
M``#4U```Y-0``/#4``#\U```"-4``!#5```<U0``*-4``#35``!`U0``3-4`
M`%C5``!DU0``;-4``'C5``"`U0``C-4``)C5``"DU0``L-4``+S5``#(U0``
MU-4``.#5``#LU0``^-4```36```0U@`````````````<U@``,-8``$C6``!8
MU@``:-8``'C6``",U@``H-8``+S6``#4U@``[-8```#7```0UP``)-<``$37
M``!8UP``;-<``(#7``"0UP``H-<``+C7``#(UP``W-<``/#7````V```$-@`
M`"#8```TV```3-@``&C8``!\V```C-@``*#8``"PV```Q-@``-C8``#HV```
M_-@```S9```8V0``*-D`````````````D-,`````````````H-,``*S3``"\
MTP``R-,``-C3``#HTP```-0``!34`````````````#34``!`U```````````
M``!,U```7-0``&S4``!\U```C-0``*#4``"LU```N-0``,34``#4U```Y-0`
M`/#4``#\U```"-4``!#5```<U0``*-4``#35``!`U0``3-4``%C5``!DU0``
M;-4``'C5``"`U0``C-4``)C5``"DU0``L-4``+S5``#(U0``U-4``.#5``#L
MU0``^-4```36```0U@`````````````<U@``,-8``$C6``!8U@``:-8``'C6
M``",U@``H-8``+S6``#4U@``[-8```#7```0UP``)-<``$37``!8UP``;-<`
M`(#7``"0UP``H-<``+C7``#(UP``W-<``/#7````V```$-@``"#8```TV```
M3-@``&C8``!\V```C-@``*#8``"PV```Q-@``-C8``#HV```_-@```S9```8
MV0``*-D```````#U`$=E=%5S97).86UE00```0!!9&1!=&]M00``G`!%>&ET
M4')O8V5S<P```+``1FEN9$%T;VU!`-8`1G)E94QI8G)A<GD```#=`$=E=$%T
M;VU.86UE00``3P%'971-;V1U;&5&:6QE3F%M94$`````40%'971-;V1U;&5(
M86YD;&5!``#C`E-E=%5N:&%N9&QE9$5X8V5P=&EO;D9I;'1E<@```%$`7W-T
M<F1U<````%4`7W-T<FYI8VUP`"<`7U]G971M86EN87)G<P`P`%]?;6)?8W5R
M7VUA>```/`!?7W!?7V5N=FER;VX``#X`7U]P7U]F;6]D90````!0`%]?<V5T
M7V%P<%]T>7!E`````&\`7V%S<V5R=````'D`7V-E>&ET`````)@`7V5R<FYO
M`````*\`7V9I;F1C;&]S90````"P`%]F:6YD9FER<W0`````LP!?9FEN9&YE
M>'0`N0!?9FUO9&4`````O`!?9G!R97-E=```Z0!?:6]B``#K`%]I<V-T>7!E
M``!9`5]M:V1I<@````!>`5]O;F5X:70```!G`5]P8W1Y<&4```!R`5]R;61I
M<@````"$`5]S971M;V1E``"X`5]U;FQI;FL````5`F%B;W)T`!P"871E>&ET
M`````#\"9G)E90``<@)M86QL;V,`````>`)M96UC<'D`````>0)M96UM;W9E
M````>@)M96US970`````D`)S:6=N86P`````DP)S<')I;G1F````F`)S=')C
M:'(`````F0)S=')C;7``````FP)S=')C<'D`````GP)S=')L96X`````H@)S
M=')N8W!Y````I@)S=')S='(`````J`)S=')T;VL`````!`!03%]M96UO<GE?
M=W)A<`````"1`%!E<FQ?1V1O7W5N9'5M<%]P='(```"X`%!E<FQ?241I<E]P
M='(`N@!097)L7TE,24]?<'1R`+T`4&5R;%])365M7W!T<@#!`%!E<FQ?25!R
M;V-?<'1R`````-T`4&5R;%])8V]M<&-V7W!T<@``Z0!097)L7TEC=7)S=&%C
M:VEN9F]?<'1R``````D!4&5R;%])979A;%]R;V]T7W!T<@````P!4&5R;%])
M97AI=%]F;&%G<U]P='(``!\!4&5R;%]):6Y?979A;%]P='(`50%097)L7TEO
M<%]P='(``&`!4&5R;%])<&%R<V5R7W!T<@``8P%097)L7TEP97)L7V1E<W1R
M=6-T7VQE=F5L7W!T<@"4`5!E<FQ?27-T871B=69?<'1R`*D!4&5R;%])=&%I
M;G1E9%]P='(`L`%097)L7TET;W!?96YV7W!T<@#R`5!E<FQ?879?9F5T8V@`
M^0%097)L7V%V7W-H:69T``X"4&5R;%]C<F]A:U]N;V-O;G1E>'0``#,"4&5R
M;%]D;W5N=VEN9`!,`E!E<FQ?9V5T7V-O;G1E>'0``'`"4&5R;%]G=E]F971C
M:'!V````[0)097)L7VUG7W-E=````#0#4&5R;%]N97=35G!V```_`U!E<FQ?
M;F5W6%,`````0`-097)L7VYE=UA37V9L86=S``"3`U!E<FQ?<V%F97-Y<VUA
M;&QO8P````"@`U!E<FQ?<V%V95]D97-T<G5C=&]R7W@`````WP-097)L7W-V
M7S)P=E]F;&%G<P`Q!%!E<FQ?<W9?<V5T<'8`8`1097)L7W-Y<U]I;FET,P``
M``!D!%!E<FQ?<WES7W1E<FT`G01B;V]T7T1Y;F%,;V%D97(```">!&)O;W1?
M5VEN,S)#3U)%`````*`$<&5R;%]A;&QO8P````"F!'!E<FQ?8V]N<W1R=6-T
M`````*<$<&5R;%]D97-T<G5C=`"H!'!E<FQ?9G)E90"J!'!E<FQ?<&%R<V4`
M````JP1P97)L7W)U;@```-```$%$5D%023,R+D1,3``````4T```%-```!30
M```4T```%-```!30```4T```%-```$M%4DY%3#,R+F1L;``````HT```*-``
M`&US=F-R="YD;&P``#S0```\T```/-```#S0```\T```/-```#S0```\T```
M/-```#S0```\T```/-```#S0```\T```/-```#S0```\T```/-```#S0```\
MT```/-```#S0```\T```/-```#S0```\T```/-```#S0```\T```/-```#S0
M```\T```/-```#S0```\T```/-```#S0``!M<W9C<G0N9&QL``!0T```4-``
M`%#0``!0T```4-```%#0``!0T```4-```%#0``!0T```4-```%#0``!0T```
M4-```%#0``!0T```4-```%#0``!0T```4-```%#0``!0T```4-```%#0``!0
MT```4-```%#0``!0T```4-```%#0``!0T```4-```%#0``!0T```4-```%#0
M``!0T```4-```%#0``!0T```4-```'!E<FPU,3`N9&QL````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````;G*20`````````,``P```"@``(`.````N```@!``
M```(`0"``````&YRDD`````````$``$```!8``"``@```'```(`#````B```
M@`0```"@``"``````&YRDD`````````!``D$```X`0```````&YRDD``````
M```!``D$``!(`0```````&YRDD`````````!``D$``!8`0```````&YRDD``
M```````!``D$``!H`0```````&YRDD`````````"`&4```#8``"`9@```/``
M`(``````;G*20`````````$`"00``'@!````````;G*20`````````$`"00`
M`(@!````````;G*20`````````$``0```"`!`(``````;G*20`````````$`
M"00``)@!``"HX0``:`4`````````````$.<``*@(`````````````+CO``!H
M!0`````````````@]0``J`@`````````````R/T``"(``````````````.S]
M```B```````````````0_@``7@(`````````````*````!`````@`````0`(
M`````````0```````````````0````$```8&!@`$!`0``@("``````!"0D(`
MG9V=`&YN;@"!@8$`L;&Q`/___P!S<W,`GY^?`%A86`"RLK(`_?W]`&MK:P#\
M_/P`U]?7`!86%@#:VMH`EI:6`(Z.C@!&1D8`R\O+``L+"P"@H*``_O[^`,G)
MR0#!P<$``P,#`!$1$0"3DY,`L[.S`.[N[@#T]/0`X^/C`.7EY0"BHJ(`NKJZ
M`*^OKP`'!P<`<7%Q`+6UM0#U]?4`B8F)`(J*B@`T-#0`Z.CH`#4U-0!:6EH`
MM[>W`-C8V`#0T-``'1T=``P,#`"/CX\`OKZ^`&UM;0`)"0D`FYN;`"\O+P#-
MS<T`V=G9`!D9&0!-34T`1$1$`%!04``\/#P`9&1D`,+"P@`R,C(`"`@(``T-
M#0`/#P\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````!04%!04%!04%!04%!04$!`0$U0",%03%#04%$12X!
M`0$!`0$!!0$\%Q<!`1,!`0$!`0$!`14!`285`0$/`0$!`0$!`0$3`1$!!34!
M)@$!`0$!`0$!(A(0,0\%`2`!`0$!`0$!`1`*("(5%2XA+@$!`0$!'R`A$"(0
M(R,E)B<!`0$!)1`0$!`0$!`0$!=%`0$!01`0$!`0$!`0$!`0%P$!`0\0$!40
M$!`0$!`0$`$!`0$2$!`3'Q`0$!`0$`<!`0$!(!`0$`$/$!`0$!$!`0$!`0<@
M$`H!`040$!`Q`0$!`0$!`0$!`0$!004/`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M@`$``,`!``#@`P``\`,``/`#``#P`P``X`,``,`!``"``0``@`$``(`#``"`
M`P````<````'``".#P``_Q\``"@````@````0`````$`"`````````0`````
M``````````$````!`````````0$!``("`@`#`P,`!`0$``4%!0`&!@8`!P<'
M``@("``)"0D`"@H*``L+"P`,#`P`#0T-``X.#@`/#P\`$!`0`!$1$0`2$A(`
M$Q,3`!04%``5%14`%A86`!<7%P`8&!@`&1D9`!H:&@`;&QL`'!P<`!T='0`>
M'AX`'Q\?`"`@(``A(2$`(B(B`",C(P`D)"0`)24E`"8F)@`G)R<`*"@H`"DI
M*0`J*BH`*RLK`"PL+``M+2T`+BXN`"\O+P`P,#``,3$Q`#(R,@`S,S,`-#0T
M`#4U-0`V-C8`-S<W`#@X.``Y.3D`.CHZ`#L[.P`\/#P`/3T]`#X^/@`_/S\`
M0$!``$%!00!"0D(`0T-#`$1$1`!%144`1D9&`$='1P!(2$@`24E)`$I*2@!+
M2TL`3$Q,`$U-30!.3DX`3T]/`%!04`!145$`4E)2`%-34P!45%0`5555`%96
M5@!75U<`6%A8`%E960!:6EH`6UM;`%Q<7`!=75T`7EY>`%]?7P!@8&``86%A
M`&)B8@!C8V,`9&1D`&5E90!F9F8`9V=G`&AH:`!I:6D`:FIJ`&MK:P!L;&P`
M;6UM`&YN;@!O;V\`<'!P`'%Q<0!R<G(`<W-S`'1T=`!U=74`=G9V`'=W=P!X
M>'@`>7EY`'IZ>@![>WL`?'Q\`'U]?0!^?GX`?W]_`("`@`"!@8$`@H*"`(.#
M@P"$A(0`A86%`(:&A@"'AX<`B(B(`(F)B0"*BHH`BXN+`(R,C`"-C8T`CHZ.
M`(^/CP"0D)``D9&1`)*2D@"3DY,`E)24`)65E0"6EI8`EY>7`)B8F`"9F9D`
MFIJ:`)N;FP"<G)P`G9V=`)Z>G@"?GY\`H*"@`*&AH0"BHJ(`HZ.C`*2DI`"E
MI:4`IJ:F`*>GIP"HJ*@`J:FI`*JJJ@"KJZL`K*RL`*VMK0"NKJX`KZ^O`+"P
ML`"QL;$`LK*R`+.SLP"TM+0`M;6U`+:VM@"WM[<`N+BX`+FYN0"ZNKH`N[N[
M`+R\O`"]O;T`OKZ^`+^_OP#`P,``P<'!`,+"P@##P\,`Q,3$`,7%Q0#&QL8`
MQ\?'`,C(R`#)R<D`RLK*`,O+RP#,S,P`S<W-`,[.S@#/S\\`T-#0`-'1T0#2
MTM(`T]/3`-34U`#5U=4`UM;6`-?7UP#8V-@`V=G9`-K:V@#;V]L`W-S<`-W=
MW0#>WMX`W]_?`.#@X`#AX>$`XN+B`./CXP#DY.0`Y>7E`.;FY@#GY^<`Z.CH
M`.GIZ0#JZNH`Z^OK`.SL[`#M[>T`[N[N`._O[P#P\/``\?'Q`/+R\@#S\_,`
M]/3T`/7U]0#V]O8`]_?W`/CX^`#Y^?D`^OKZ`/O[^P#\_/P`_?W]`/[^_@#_
M__\`-#0T/#P\/#P\/#P\/#P\/#P\/#P\/#P\+`P$!`0$!`1<M-34U-34U-34
MU-3<U-34U-34U-34U-2T-%$$!`0$!&3,[/3T]/ST_/3T]/ST_/3\]/S\_/3T
M[,0T45$$!`0$9,3D[/3T]/3T]/3T]/3T]/3T]/3T].SLO#1145$$!`1DQ.3L
M[.SD[.SLY.3DY.SLY.SD[.SL[.2\-%%145$$!&2\Y.SLK(RLU,24E)R4C(R4
ME)2<G)SLW+PT45%145$$9+S<Y.SDQ%&4K&3DI$PT+%S$S%&TU.3<O#1145%1
M45%DO-SDY.SDY%&$=.2,;*2<;(R\=*S4Y-R\-`0$!`0$!&2\W.3D[.3DO%&,
MU-2,K,QTS-RD4<3DW+PT!`0$!`0$9+S<Y.3DY.3<C'R<M'R$G&S,Y+QTQ.3<
MM#0$!`0$!`1<O-S<Y.3DY-2<I%R4C,P\E&3,O(Q1W-2T-`0$!`0$!&2TU-S<
MW.3<C(RL++RTS%K$9)QLE*3<U+0T!`0$!`0$7+34W-SDW-QTE-1,I/2,/-1T
ME'2<3-S,M#0$!`0$!`1DM-3<W-SDW'11]'2$[,QDY'QLI+1LI-2T-`0$!`0$
M!&2TS-S<S'R,A+3\S,3\]+3\O&3,K(11O*PT!`0$!`0$7+3,U,R,I-S<[/S\
M_/S\]/SLM.RL?)11K#0$!`0$!`1<K,S,;)ST_/S\_/S\_/S\_/S\_,24C%&L
M-`0$!`0$!%RLQ+Q\Y/S\_/S\_/S\_/S\_/S\[,RL4:PT!`0$!`0$7*RT3,3\
M_/SL]/S\_/S\_/S\_/STO%'$K#0$!`0$!`1<K+1,U/S\]+3<_/S\_/S\_/S\
M_,Q1S,2D-`0$!`0$!%RLQ*11_/S\M)ST_/S\_/S\_/STE%',Q*0L!`0$!`0$
M7*2D483L_/S,9+3L_/S\_/S\_-1LK,R\I#0$!`0$!`1<I&1TO/3\_,11A)SD
M_/S\_/SDC%',S,2D-`0$!`0$!%RD;(SD]/S\G%',493L_/S\_+QTS,S$O)PL
M!`0$!`0$7*2L9%QDI*11K,S$=)3D]/SD4;S,S,2\G#0$!`0$!`1<I+2\O(Q1
M4<3$S,RL47Q\E&Q\O,S$Q+R<+`0$!`0$!%R<O,3$Q,3$Q,3$Q,3$45%14;S$
MQ,3$M)PT!`0$!`0$5)RTQ,3$Q,3$Q,3$Q,3$Q,3$Q,3$Q+RTG"P$!`0$!`14
MG+S$Q+R\O+R\O+R\O+R\O+R\O+R\O+2<+`0$!`0$!%R<M,2\M+2TM+2TM+2T
MM+2TM+2TM+2TK)PL!`0$!`0$5(24G)R4E)24E)24E)24E)24E)24E)24A"0$
M!`0$!`1$5%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%Q4-`0$!`0$!````#\````?
M````#P````<````#`````0`````````_````/P```#\````_````/P```#\`
M```_````/P```#\````_````/P```#\````_````/P```#\````_````/P``
M`#\````_````/P```#\````_````/P```#\````_*````!`````@`````0`(
M`````````0```````````````0````$```8&!@`$!`0``@("``````!"0D(`
MG9V=`&YN;@"!@8$`L;&Q`/___P!S<W,`GY^?`%A86`"RLK(`_?W]`&MK:P#\
M_/P`U]?7`!86%@#:VMH`EI:6`(Z.C@!&1D8`R\O+``L+"P"@H*``_O[^`,G)
MR0#!P<$``P,#`!$1$0"3DY,`L[.S`.[N[@#T]/0`X^/C`.7EY0"BHJ(`NKJZ
M`*^OKP`'!P<`<7%Q`+6UM0#U]?4`B8F)`(J*B@`T-#0`Z.CH`#4U-0!:6EH`
MM[>W`-C8V`#0T-``'1T=``P,#`"/CX\`OKZ^`&UM;0`)"0D`FYN;`"\O+P#-
MS<T`V=G9`!D9&0!-34T`1$1$`%!04``\/#P`9&1D`,+"P@`R,C(`"`@(``T-
M#0`/#P\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````!04%!04%!04%!04%!04$!`0$U0",%03%#04%$12X!
M`0$!`0$!!0$\%Q<!`1,!`0$!`0$!`14!`285`0$/`0$!`0$!`0$3`1$!!34!
M)@$!`0$!`0$!(A(0,0\%`2`!`0$!`0$!`1`*("(5%2XA+@$!`0$!'R`A$"(0
M(R,E)B<!`0$!)1`0$!`0$!`0$!=%`0$!01`0$!`0$!`0$!`0%P$!`0\0$!40
M$!`0$!`0$`$!`0$2$!`3'Q`0$!`0$`<!`0$!(!`0$`$/$!`0$!$!`0$!`0<@
M$`H!`040$!`Q`0$!`0$!`0$!`0$!004/`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M@`$``,`!``#@`P``\`,``/`#``#P`P``X`,``,`!``"``0``@`$``(`#``"`
M`P````<````'``".#P``_Q\``"@````@````0`````$`"`````````0`````
M``````````$````!`````````0$!``("`@`#`P,`!`0$``4%!0`&!@8`!P<'
M``@("``)"0D`"@H*``L+"P`,#`P`#0T-``X.#@`/#P\`$!`0`!$1$0`2$A(`
M$Q,3`!04%``5%14`%A86`!<7%P`8&!@`&1D9`!H:&@`;&QL`'!P<`!T='0`>
M'AX`'Q\?`"`@(``A(2$`(B(B`",C(P`D)"0`)24E`"8F)@`G)R<`*"@H`"DI
M*0`J*BH`*RLK`"PL+``M+2T`+BXN`"\O+P`P,#``,3$Q`#(R,@`S,S,`-#0T
M`#4U-0`V-C8`-S<W`#@X.``Y.3D`.CHZ`#L[.P`\/#P`/3T]`#X^/@`_/S\`
M0$!``$%!00!"0D(`0T-#`$1$1`!%144`1D9&`$='1P!(2$@`24E)`$I*2@!+
M2TL`3$Q,`$U-30!.3DX`3T]/`%!04`!145$`4E)2`%-34P!45%0`5555`%96
M5@!75U<`6%A8`%E960!:6EH`6UM;`%Q<7`!=75T`7EY>`%]?7P!@8&``86%A
M`&)B8@!C8V,`9&1D`&5E90!F9F8`9V=G`&AH:`!I:6D`:FIJ`&MK:P!L;&P`
M;6UM`&YN;@!O;V\`<'!P`'%Q<0!R<G(`<W-S`'1T=`!U=74`=G9V`'=W=P!X
M>'@`>7EY`'IZ>@![>WL`?'Q\`'U]?0!^?GX`?W]_`("`@`"!@8$`@H*"`(.#
M@P"$A(0`A86%`(:&A@"'AX<`B(B(`(F)B0"*BHH`BXN+`(R,C`"-C8T`CHZ.
M`(^/CP"0D)``D9&1`)*2D@"3DY,`E)24`)65E0"6EI8`EY>7`)B8F`"9F9D`
MFIJ:`)N;FP"<G)P`G9V=`)Z>G@"?GY\`H*"@`*&AH0"BHJ(`HZ.C`*2DI`"E
MI:4`IJ:F`*>GIP"HJ*@`J:FI`*JJJ@"KJZL`K*RL`*VMK0"NKJX`KZ^O`+"P
ML`"QL;$`LK*R`+.SLP"TM+0`M;6U`+:VM@"WM[<`N+BX`+FYN0"ZNKH`N[N[
M`+R\O`"]O;T`OKZ^`+^_OP#`P,``P<'!`,+"P@##P\,`Q,3$`,7%Q0#&QL8`
MQ\?'`,C(R`#)R<D`RLK*`,O+RP#,S,P`S<W-`,[.S@#/S\\`T-#0`-'1T0#2
MTM(`T]/3`-34U`#5U=4`UM;6`-?7UP#8V-@`V=G9`-K:V@#;V]L`W-S<`-W=
MW0#>WMX`W]_?`.#@X`#AX>$`XN+B`./CXP#DY.0`Y>7E`.;FY@#GY^<`Z.CH
M`.GIZ0#JZNH`Z^OK`.SL[`#M[>T`[N[N`._O[P#P\/``\?'Q`/+R\@#S\_,`
M]/3T`/7U]0#V]O8`]_?W`/CX^`#Y^?D`^OKZ`/O[^P#\_/P`_?W]`/[^_@#_
M__\`-#0T/#P\/#P\/#P\/#P\/#P\/#P\/#P\+`P$!`0$!`1<M-34U-34U-34
MU-3<U-34U-34U-34U-2T-%$$!`0$!&3,[/3T]/ST_/3T]/ST_/3\]/S\_/3T
M[,0T45$$!`0$9,3D[/3T]/3T]/3T]/3T]/3T]/3T].SLO#1145$$!`1DQ.3L
M[.SD[.SLY.3DY.SLY.SD[.SL[.2\-%%145$$!&2\Y.SLK(RLU,24E)R4C(R4
ME)2<G)SLW+PT45%145$$9+S<Y.SDQ%&4K&3DI$PT+%S$S%&TU.3<O#1145%1
M45%DO-SDY.SDY%&$=.2,;*2<;(R\=*S4Y-R\-`0$!`0$!&2\W.3D[.3DO%&,
MU-2,K,QTS-RD4<3DW+PT!`0$!`0$9+S<Y.3DY.3<C'R<M'R$G&S,Y+QTQ.3<
MM#0$!`0$!`1<O-S<Y.3DY-2<I%R4C,P\E&3,O(Q1W-2T-`0$!`0$!&2TU-S<
MW.3<C(RL++RTS%K$9)QLE*3<U+0T!`0$!`0$7+34W-SDW-QTE-1,I/2,/-1T
ME'2<3-S,M#0$!`0$!`1DM-3<W-SDW'11]'2$[,QDY'QLI+1LI-2T-`0$!`0$
M!&2TS-S<S'R,A+3\S,3\]+3\O&3,K(11O*PT!`0$!`0$7+3,U,R,I-S<[/S\
M_/S\]/SLM.RL?)11K#0$!`0$!`1<K,S,;)ST_/S\_/S\_/S\_/S\_,24C%&L
M-`0$!`0$!%RLQ+Q\Y/S\_/S\_/S\_/S\_/S\[,RL4:PT!`0$!`0$7*RT3,3\
M_/SL]/S\_/S\_/S\_/STO%'$K#0$!`0$!`1<K+1,U/S\]+3<_/S\_/S\_/S\
M_,Q1S,2D-`0$!`0$!%RLQ*11_/S\M)ST_/S\_/S\_/STE%',Q*0L!`0$!`0$
M7*2D483L_/S,9+3L_/S\_/S\_-1LK,R\I#0$!`0$!`1<I&1TO/3\_,11A)SD
M_/S\_/SDC%',S,2D-`0$!`0$!%RD;(SD]/S\G%',493L_/S\_+QTS,S$O)PL
M!`0$!`0$7*2L9%QDI*11K,S$=)3D]/SD4;S,S,2\G#0$!`0$!`1<I+2\O(Q1
M4<3$S,RL47Q\E&Q\O,S$Q+R<+`0$!`0$!%R<O,3$Q,3$Q,3$Q,3$45%14;S$
MQ,3$M)PT!`0$!`0$5)RTQ,3$Q,3$Q,3$Q,3$Q,3$Q,3$Q+RTG"P$!`0$!`14
MG+S$Q+R\O+R\O+R\O+R\O+R\O+R\O+2<+`0$!`0$!%R<M,2\M+2TM+2TM+2T
MM+2TM+2TM+2TK)PL!`0$!`0$5(24G)R4E)24E)24E)24E)24E)24E)24A"0$
M!`0$!`1$5%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%Q4-`0$!`0$!````#\````?
M````#P````<````#`````0`````````_````/P```#\````_````/P```#\`
M```_````/P```#\````_````/P```#\````_````/P```#\````_````/P``
M`#\````_````/P```#\````_````/P```#\````_```!``(`$!````$`"`!H
M!0```0`@(````0`(`*@(```"```````!``(`$!````$`"`!H!0```P`@(```
M`0`(`*@(```$````7@(T````5@!3`%\`5@!%`%(`4P!)`$\`3@!?`$D`3@!&
M`$\``````+T$[_X```$`````````````````````````````````!``$``$`
M```````````````````"`@````!3`'0`<@!I`&X`9P!&`&D`;`!E`$D`;@!F
M`&\```#>`0`````P`#0`,``P`#``-`!B`#`````:``$``0!#`&\`;0!M`&4`
M;@!T`',`````````(@`!``$`0P!O`&T`<`!A`&X`>0!.`&$`;0!E````````
M````*@`!``$`1@!I`&P`90!$`&4`<P!C`'(`:0!P`'0`:0!O`&X`````````
M```B``$``0!&`&D`;`!E`%8`90!R`',`:0!O`&X````````````B``$``0!)
M`&X`=`!E`'(`;@!A`&P`3@!A`&T`90`````````F``$``0!,`&4`9P!A`&P`
M0P!O`'``>0!R`&D`9P!H`'0`````````*@`!``$`3`!E`&<`80!L`%0`<@!A
M`&0`90!M`&$`<@!K`',````````````J``$``0!/`'(`:0!G`&D`;@!A`&P`
M1@!I`&P`90!N`&$`;0!E`````````"(``0`!`%``<@!I`'8`80!T`&4`0@!U
M`&D`;`!D`````````"(``0`!`%``<@!O`&0`=0!C`'0`3@!A`&T`90``````
M`````"8``0`!`%``<@!O`&0`=0!C`'0`5@!E`'(`<P!I`&\`;@`````````B
M``$``0!3`'``90!C`&D`80!L`$(`=0!I`&P`9```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
>````````````````````````````````````````
